@@ -352,6 +352,13 @@ class CognitoIdpResponse(BaseResponse):
         cognitoidp_backends[region].change_password(access_token, previous_password, proposed_password)
         return ""
 
+    def admin_update_user_attributes(self):
+        user_pool_id = self._get_param("UserPoolId")
+        username = self._get_param("Username")
+        attributes = self._get_param("UserAttributes")
+        cognitoidp_backends[self.region].admin_update_user_attributes(user_pool_id, username, attributes)
+        return ""
+
 
 class CognitoIdpJsonWebKeyResponse(BaseResponse):
 
